@@ -4,12 +4,19 @@
 
 """Bridge
 
-The Bridge Component is used for inter-process communications between
-processes. Bridge is used internally when a Component is started in
-"process mode" via :meth:`circuits.core.manager.start`. Typically a
-Pipe is used as the socket transport between two sides of a Bridge
-(*there must be a :class:`~Bridge` instnace on both sides*).
+Bridge Component to Bridge one or more components in a single System.
+That is, events in System A bridged to System B are shared. For example:
 
+A <--> Bridge <--> B
+
+Events that propagate in A, will propagate to B across the Bridge.
+Events that propagate in B, will propagate to A across the Bridge.
+
+When the Bridge is created, it will automatically attempt to send a
+Helo Event to any configured nodes or on a broadcast address if no
+nodes are initially configured. The default Bridge implementation
+uses the UDP protocol and as such events cannot be guaranteed of their
+order or delivery.
 """
 
 try:
