@@ -2,14 +2,11 @@
 .. codeauthor: mnl
 """
 
-
-from sys import stderr
 from threading import Event
-from signal import SIGINT, SIGTERM
-
 
 from .handlers import handler
 from .components import BaseComponent
+import sys
 from circuits.core.handlers import reprhandler
 
 
@@ -27,7 +24,7 @@ class FallBackGenerator(BaseComponent):
         When the queue is empty a GenerateEvents event is fired, here
         we sleep for as long as possible to avoid using extra cpu cycles.
 
-        A poller would override this with a higher priority handler.
+        A poller would override with with a higher priority handler.
         e.g: ``@handler("generate_events", priority=0)``
         and provide a different way to idle when the queue is empty.
         """
@@ -71,7 +68,7 @@ class FallBackGenerator(BaseComponent):
 
 class FallBackErrorHandler(BaseComponent):
     """
-    If there is no handler for error events in the component hierarchy, this
+    If ther is no handler for error events in the component hierarchy, this
     component's handler is added automatically. It simply prints
     the error information on stderr.
     """
@@ -86,24 +83,8 @@ class FallBackErrorHandler(BaseComponent):
         else:
             handler = reprhandler(handler)
 
-        msg = "ERROR {0:s} ({1:s}) ({2:s}): {3:s}\n".format(
-            handler, repr(fevent), repr(error_type), repr(value)
-        )
-
+        msg = "ERROR %s (%s) {%s}: %s\n" % (handler, fevent, error_type, value)
         s.append(msg)
         s.extend(traceback)
         s.append("\n")
-        stderr.write("".join(s))
-
-
-class FallBackSignalHandler(BaseComponent):
-    """
-    If there is no handler for signal events in the component hierarchy, this
-    component's handler is added automatically. It simply terminates the
-    system if the signal is SIGINT or SIGTERM.
-    """
-
-    @handler("signal", channel="*")
-    def _on_signal(self, signo, stack):
-        if signo in [SIGINT, SIGTERM]:
-            raise SystemExit(0)
+        sys.stderr.write("".join(s))
