@@ -2,7 +2,6 @@
 # Date:     13th September 2007
 # Author:   James Mills, prologic at shortcircuit dot net dot au
 
-
 """Hyper Text Transfer Protocol
 
 This module implements the server side Hyper Text Transfer Protocol
@@ -101,10 +100,8 @@ class HTTP(BaseComponent):
             return
         return self.uri.utf8().rstrip(b"/").decode(self._encoding)
 
-    @handler("stream")  # noqa
+    @handler("stream")
     def _on_stream(self, res, data):
-        sock = res.request.sock
-
         if data is not None:
             if isinstance(data, text_type):
                 data = data.encode(self._encoding)
@@ -118,7 +115,7 @@ class HTTP(BaseComponent):
                 ]
                 data = b"".join(buf)
 
-            self.fire(write(sock, data))
+            self.fire(write(res.request.sock, data))
 
             if res.body and not res.done:
                 try:
@@ -132,15 +129,13 @@ class HTTP(BaseComponent):
             if res.body:
                 res.body.close()
             if res.chunked:
-                self.fire(write(sock, b"0\r\n\r\n"))
+                self.fire(write(res.request.sock, b"0\r\n\r\n"))
             if res.close:
-                self.fire(close(sock))
-            if sock in self._clients:
-                del self._clients[sock]
-
+                self.fire(close(res.request.sock))
+            del self._clients[res.request.sock]
             res.done = True
 
-    @handler("response")  # noqa
+    @handler("response")
     def _on_response(self, res):
         """``Response`` Event Handler
 
@@ -213,7 +208,7 @@ class HTTP(BaseComponent):
         if sock in self._clients:
             del self._clients[sock]
 
-    @handler("read")  # noqa
+    @handler("read")
     def _on_read(self, sock, data):
         """Read Event Handler
 
@@ -225,7 +220,7 @@ class HTTP(BaseComponent):
         if sock in self._buffers:
             parser = self._buffers[sock]
         else:
-            self._buffers[sock] = parser = HttpParser(0, True)
+            self._buffers[sock] = parser = HttpParser(0, True, self._encoding)
 
             # If we receive an SSL handshake at the start of a request
             # and we're not a secure server, then immediately close the
@@ -328,7 +323,7 @@ class HTTP(BaseComponent):
         res.body = str(event)
         self.fire(response(res))
 
-    @handler("request_success")  # noqa
+    @handler("request_success")
     def _on_request_success(self, e, value):
         """
         Handler for the ``RequestSuccess`` event that is automatically
@@ -430,13 +425,7 @@ class HTTP(BaseComponent):
             self.fire(response(res))
 
     @handler("error")
-    def _on_error(self, *args, **kwargs):
-        if not len(args) == 3:
-            return
-
-        etype, evalue, etraceback = args
-        fevent = kwargs["fevent"]
-
+    def _on_error(self, etype, evalue, etraceback, handler=None, fevent=None):
         if isinstance(fevent, response):
             res = fevent.args[0]
             sock = res.request.sock
@@ -500,24 +489,12 @@ class HTTP(BaseComponent):
 
     @handler("request_complete")
     def _on_request_complete(self, *args, **kwargs):
-        """Dummy Event Handler for request events
-
-        - request_complete
-        """
+        """Dummy Event Handler for request_complete"""
 
     @handler("response_success", "response_complete")
     def _on_response_feedback(self, *args, **kwargs):
-        """Dummy Event Handler for response events
-
-        - response_success
-        - response_complete
-        """
+        """Dummy Event Handler for response_success and response_complete"""
 
     @handler("stream_success", "stream_failure", "stream_complete")
     def _on_stream_feedback(self, *args, **kwargs):
-        """Dummy Event Handler for stream events
-
-        - stream_success
-        - stream_failure
-        - stream_complete
-        """
+        """Dummy Event Handler for stream_success, stream_failure and stream_complete"""
