@@ -17,4 +17,6 @@ class Root(Controller):
     def getrange(self, limit=4):
         return range(int(limit))
 
-(Server(8000) + Root()).run()
+app = Server(("0.0.0.0", 8000))
+Root().register(app)
+app.run()
