@@ -1,19 +1,16 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-
 """wget Example
 
 A basic wget-like clone that asynchronously connections
 a remote web server requesting a given resource.
 """
 
-
 import sys
 
-
 from circuits import Component
-from circuits.web.client import Client, request
+from circuits.web.client import Client, Request
 
 
 class WebClient(Component):
@@ -24,7 +21,7 @@ class WebClient(Component):
         Client().register(self)
 
     def ready(self, *args):
-        self.fire(request("GET", self.url))
+        self.fire(Request("GET", self.url))
 
     def response(self, response):
         print("{0:d} {1:s}".format(response.status, response.reason))
@@ -37,5 +34,4 @@ class WebClient(Component):
         print(response.read())
         raise SystemExit(0)
 
-
 WebClient(sys.argv[1]).run()
