@@ -7,11 +7,11 @@ import pytest
 from circuits import Event, Loader, Manager
 
 
-class Test(Event):
-    """Test Event"""
+class test(Event):
+    """test Event"""
 
 
-def test():
+def test_main():
     m = Manager()
     loader = Loader(paths=[dirname(__file__)]).register(m)
 
@@ -19,7 +19,7 @@ def test():
 
     loader.load("app")
 
-    x = m.fire(Test())
+    x = m.fire(test())
 
     assert pytest.wait_for(x, "result")
 
