@@ -5,19 +5,16 @@ if pytest.PLATFORM == "win32":
     pytest.skip("Broken on Windows")
 
 from circuits import Component, Event
-from circuits.net.sockets import Close
-from circuits.node import Node, Remote
+from circuits.net.events import close
+from circuits.node import Node, remote
 from circuits.net.sockets import UDPServer
 
 
-class Foo(Event):
-    """Foo Event"""
-
-
 class App(Component):
-    disconnected = False
+
     ready = False
     value = False
+    disconnected = False
 
     def foo(self):
         return "Hello World!"
@@ -39,10 +36,11 @@ def bind(manager, watcher):
 
     host, port = server.host, server.port
 
-    server.fire(Close())
+    server.fire(close())
     assert watcher.wait("closed")
 
     server.unregister()
+    assert watcher.wait("unregistered")
 
     return host, port
 
@@ -50,20 +48,22 @@ def bind(manager, watcher):
 def test_return_value(manager, watcher, bind):
     a1 = App().register(manager)
     n1 = Node().register(a1)
+    assert watcher.wait("ready")
 
     a2 = (App() + Node(bind))
     a2.start(process=True)
 
     n1.add("a2", *bind)
+    assert watcher.wait("connected")
 
     e = Event.create("foo")
     e.notify = True
 
-    r = Remote(e, "a2")
+    r = remote(e, "a2")
     r.notify = True
 
     value = a1.fire(r)
-    watcher.wait("remote_value_changed")
+    assert watcher.wait("remote_value_changed")
 
     assert value.value == "Hello World!"
 
